@@ -13,15 +13,15 @@
 #'
 #' @param surface character string or `fs.surface` instance. The display surface. E.g., "white", "pial", or "inflated". Defaults to "white".
 #'
-#' @param colormap a colormap function. See the squash package for some colormaps. Defaults to \code{\link[squash]{jet}}.
+#' @param colormap a colormap function. See the squash package for some colormaps. Defaults to \code{\link{jet}}.
 #'
 #' @param clip numeric vector of length 2 or NULL. If given, the 2 values are interpreted as lower and upper percentiles, and the morph data is clipped at the given lower and upper percentile (see \code{\link[fsbrain]{clip.data}}). Defaults to NULL (no data clipping).
 #'
 #' @param cortex_only logical, whether to mask the medial wall, i.e., whether the morphometry data for all vertices which are *not* part of the cortex (as defined by the label file `label/?h.cortex.label`) should be replaced with NA values. In other words, setting this to TRUE will ignore the values of the medial wall between the two hemispheres. If set to true, the mentioned label file needs to exist for the subject. Defaults to FALSE.
 #'
-#' @param makecmap_options named list of parameters to pass to \code{\link[squash]{makecmap}}. Must not include the unnamed first parameter, which is derived from 'measure'.
+#' @param makecmap_options named list of parameters to pass to \code{\link{makecmap}}. Must not include the unnamed first parameter, which is derived from 'measure'.
 #'
-#' @return coloredmesh. A named list with entries: "mesh" the \code{\link[rgl]{tmesh3d}} mesh object. "col": the mesh colors. "render", logical, whether to render the mesh. "hemi": the hemisphere, one of 'lh' or 'rh'.
+#' @return coloredmesh. A named list with entries: "mesh" the \code{\link{tmesh3d}} mesh object. "col": the mesh colors. "render", logical, whether to render the mesh. "hemi": the hemisphere, one of 'lh' or 'rh'.
 #'
 #' @family coloredmesh functions
 #'
@@ -81,7 +81,7 @@ coloredmesh.from.morph.native <- function(subjects_dir, subject_id, measure, hem
 #'
 #' @param color_data vector of hex color strings
 #'
-#' @return coloredmesh. A named list with entries: "mesh" the \code{\link[rgl]{tmesh3d}} mesh object. "col": the mesh colors. "render", logical, whether to render the mesh. "hemi": the hemisphere, one of 'lh' or 'rh'.
+#' @return coloredmesh. A named list with entries: "mesh" the \code{\link{tmesh3d}} mesh object. "col": the mesh colors. "render", logical, whether to render the mesh. "hemi": the hemisphere, one of 'lh' or 'rh'.
 #'
 #' @note Do not call this, use \code{\link[fsbrain]{coloredmeshes.from.color}} instead.
 #'
@@ -127,7 +127,7 @@ coloredmesh.from.color <- function(subjects_dir, subject_id, color_data, hemi, s
 #'
 #' @param metadata a named list, can contain whatever you want. Typical entries are: 'src_data' a hemilist containing the source data from which the 'color_data' was created, optional. If available, it is encoded into the coloredmesh and can be used later to plot a colorbar. 'makecmap_options': the options used to created the colormap from the data.
 #'
-#' @return named list of coloredmeshes. Each entry is a named list with entries: "mesh" the \code{\link[rgl]{tmesh3d}} mesh object. "col": the mesh colors. "render", logical, whether to render the mesh. "hemi": the hemisphere, one of 'lh' or 'rh'.
+#' @return named list of coloredmeshes. Each entry is a named list with entries: "mesh" the \code{\link{tmesh3d}} mesh object. "col": the mesh colors. "render", logical, whether to render the mesh. "hemi": the hemisphere, one of 'lh' or 'rh'.
 #'
 #' @family coloredmesh functions
 #'
@@ -164,7 +164,7 @@ coloredmeshes.from.color <- function(subjects_dir, subject_id, color_data, hemi,
 #
 #' @param template_subjects_dir The template subjects dir. If `NULL`, the value of the parameter 'subjects_dir' is used. Defaults to NULL. If you have FreeSurfer installed and configured, and are using the standard fsaverage subject, try passing the result of calling 'file.path(Sys.getenv('FREESURFER_HOME'), 'subjects')'.
 #'
-#' @return coloredmesh. A named list with entries: "mesh" the \code{\link[rgl]{tmesh3d}} mesh object. "col": the mesh colors. "render", logical, whether to render the mesh. "hemi": the hemisphere, one of 'lh' or 'rh'.
+#' @return coloredmesh. A named list with entries: "mesh" the \code{\link{tmesh3d}} mesh object. "col": the mesh colors. "render", logical, whether to render the mesh. "hemi": the hemisphere, one of 'lh' or 'rh'.
 #'
 #' @family coloredmesh functions
 #'
@@ -237,7 +237,7 @@ coloredmesh.from.morph.standard <- function(subjects_dir, subject_id, measure, h
 #'
 #' @param morph_data string. The morphometry data to use. E.g., 'area' or 'thickness.'
 #'
-#' @return coloredmesh. A named list with entries: "mesh" the \code{\link[rgl]{tmesh3d}} mesh object. "col": the mesh colors. "render", logical, whether to render the mesh. "hemi": the hemisphere, one of 'lh' or 'rh'.
+#' @return coloredmesh. A named list with entries: "mesh" the \code{\link{tmesh3d}} mesh object. "col": the mesh colors. "render", logical, whether to render the mesh. "hemi": the hemisphere, one of 'lh' or 'rh'.
 #'
 #' @family coloredmesh functions
 #'
@@ -275,6 +275,48 @@ coloredmesh.from.morphdata <- function(subjects_dir, vis_subject_id, morph_data,
 }
 
 
+#' @title Generate coloredmesh from loaded data.
+#'
+#' @param fs_surface an fs.surface instance
+#'
+#' @param morph_data numerical vector, per-vertex data (typically morphometry) for the mesh. If given, takes precedence over 'col' parameter.
+#'
+#' @param col vector of colors, typically hex color strings like '#FF00FF'. The per-vertex-colors for the mesh. Alternative to morph_data.
+#'
+#' @param hemi character string, one of 'lh' or 'rh'. Metadata, the hemisphere. May be used by visualization functions to decide whether to draw the mesh in certain views.
+#'
+#' @inheritParams coloredmesh.from.morphdata
+#'
+#' @return as fs.coloredmesh instance
+#'
+#' @export
+coloredmesh.from.preloaded.data <- function(fs_surface, morph_data=NULL, col=NULL, hemi='lh', makecmap_options=mkco.seq()) {
+    if( ! freesurferformats::is.fs.surface(fs_surface)) {
+        stop("Parameter 'fs_surface' must be an fs.surface instance");
+    }
+    mesh = rgl::tmesh3d(c(t(fs_surface$vertices)), c(t(fs_surface$faces)), homogeneous=FALSE);
+    if(! is.null(morph_data)) {
+        if(! hasIn(makecmap_options, c('colFn'))) {
+            makecmap_options$colFn = mkco.seq()$colFn;
+        }
+        data_range = range(morph_data, finite=TRUE);
+        map = do.call(squash::makecmap, utils::modifyList(list(morph_data), makecmap_options));
+        col = squash::cmap(morph_data, map = map);
+    } else {
+        map = NULL;
+        data_range = NULL;
+        if(is.null(col)) {
+            col = rep("#FFFFFF", nrow(fs_surface$vertices));
+        }
+        if(length(col) == 1L) {
+            col = rep(col, nrow(fs_surface$vertices));
+        }
+    }
+
+    return(fs.coloredmesh(mesh, col, hemi, metadata=list("src_data"=morph_data, "fs_mesh"=fs_surface, "map"=map, "data_range"=data_range, "cmap_fun"=makecmap_options$colFn)));
+}
+
+
 
 #' @title Create a coloredmesh from an annotation of an atlas.
 #'
@@ -284,7 +326,7 @@ coloredmesh.from.morphdata <- function(subjects_dir, vis_subject_id, morph_data,
 #'
 #' @param outline logical, whether to draw an outline only instead of filling the regions. Defaults to FALSE. Only makes sense if you did not pass an outline already. The current implementation for outline computation is rather slow, so setting this to TRUE will considerably increase computation time.
 #'
-#' @return coloredmesh. A named list with entries: "mesh" the \code{\link[rgl]{tmesh3d}} mesh object. "col": the mesh colors. "render", logical, whether to render the mesh. "hemi": the hemisphere, one of 'lh' or 'rh'.
+#' @return coloredmesh. A named list with entries: "mesh" the \code{\link{tmesh3d}} mesh object. "col": the mesh colors. "render", logical, whether to render the mesh. "hemi": the hemisphere, one of 'lh' or 'rh'.
 #'
 #' @family coloredmesh functions
 #'
@@ -340,7 +382,7 @@ coloredmesh.from.annot <- function(subjects_dir, subject_id, atlas, hemi, surfac
 #'
 #' @param label string or vector of integers. If a string, the name of the label file, without the hemi part (if any), but including the '.label' suffix. E.g., 'cortex.label' for '?h.cortex.label'. Alternatively, the already loaded label data as a vector of integers.
 #'
-#' @return coloredmesh. A named list with entries: "mesh" the \code{\link[rgl]{tmesh3d}} mesh object. "col": the mesh colors. "render", logical, whether to render the mesh. "hemi": the hemisphere, one of 'lh' or 'rh'.
+#' @return coloredmesh. A named list with entries: "mesh" the \code{\link{tmesh3d}} mesh object. "col": the mesh colors. "render", logical, whether to render the mesh. "hemi": the hemisphere, one of 'lh' or 'rh'.
 #'
 #' @family coloredmesh functions
 #'
@@ -381,7 +423,7 @@ coloredmesh.from.label <- function(subjects_dir, subject_id, label, hemi, surfac
 #'
 #' @param surface_data optional surface mesh object, as returned by \code{\link[fsbrain]{subject.surface}}. If given, used instead of loading the surface data from disk (which users of this function may already have done). Defaults to NULL.
 #'
-#' @return coloredmesh. A named list with entries: "mesh" the \code{\link[rgl]{tmesh3d}} mesh object. "col": the mesh colors. "render", logical, whether to render the mesh. "hemi": the hemisphere, one of 'lh' or 'rh'.
+#' @return coloredmesh. A named list with entries: "mesh" the \code{\link{tmesh3d}} mesh object. "col": the mesh colors. "render", logical, whether to render the mesh. "hemi": the hemisphere, one of 'lh' or 'rh'.
 #'
 #' @family mask functions
 #' @family coloredmesh functions
@@ -450,30 +492,40 @@ is.fs.coloredmesh <- function(x) inherits(x, "fs.coloredmesh")
 
 #' @title fs.coloredmesh constructor
 #'
-#' @param mesh a `mesh3d` instance as returned by \code{\link[rgl]{tmesh3d}} or an `fs.surface` brain surface mesh as returned by functions like \code{\link[fsbrain]{subject.surface}}.
+#' @param mesh a `mesh3d` instance as returned by \code{\link{tmesh3d}} or an `fs.surface` brain surface mesh as returned by functions like \code{\link[fsbrain]{subject.surface}}.
 #'
-#' @param col vector of vertex colors for the mesh, one color per vertex
+#' @param col vector of vertex colors for the mesh, one color per vertex. Expanded if exactly one color.
 #'
-#' @param hemi character string, one of 'lh' or 'rh'
+#' @param hemi character string, one of 'lh' or 'rh'. This may be used by visualization functions to decide whether or not to show this mesh in a certain view.
 #'
 #' @param render logical, whether to render this mesh during visualization
 #'
 #' @param metadata optional, named list containing metadata
 #'
+#' @param add_normals logical, whether to compute normals and save them in the mesh.
+#'
 #' @return an `fs.coloredmesh` instance. The only fields one should use in client code are 'mesh', 'hemi' and 'col', all others are considered internal and may change without notice.
 #'
 #' @importFrom freesurferformats is.fs.surface
-#' @importFrom rgl tmesh3d
+#' @importFrom rgl tmesh3d addNormals
 #' @export
-fs.coloredmesh <- function(mesh, col, hemi, render=TRUE, metadata=NULL) {
+fs.coloredmesh <- function(mesh, col, hemi, render=TRUE, metadata=NULL, add_normals=FALSE) {
     if(freesurferformats::is.fs.surface(mesh)) {
         mesh = rgl::tmesh3d(c(t(mesh$vertices)), c(t(mesh$faces)), homogeneous=FALSE);
     }
     if(!inherits(mesh, "mesh3d")) {
         stop("Parameter 'mesh' must be a mesh3d or fs.surface instance.");
     }
+    if(add_normals) {
+        mesh = rgl::addNormals(mesh);
+    }
+
     if(ncol(mesh$vb) != length(col)) {
-        warning(sprintf("The mesh3d instance from parameter 'mesh' has %d vertices, but %d colors passed in parameter 'col'.\n", ncol(mesh$vb), length(col)));
+        if(length(col) == 1L) {
+            col = rep(col, ncol(mesh$vb));
+        } else {
+            warning(sprintf("The mesh3d instance from parameter 'mesh' has %d vertices, but %d colors passed in parameter 'col'.\n", ncol(mesh$vb), length(col)));
+        }
     }
     if(!is.null(hemi)) {
         if(!(hemi %in% c("lh", "rh"))) {
@@ -490,7 +542,7 @@ fs.coloredmesh <- function(mesh, col, hemi, render=TRUE, metadata=NULL) {
 
     md_entries = names(metadata);
     for (mde in md_entries) {
-        if(! mde %in% c("src_data", "fs_mesh", "data_range", "makecmap_options", "map", "map_sorted", "col_sorted")) {
+        if(! mde %in% c("src_data", "fs_mesh", "data_range", "makecmap_options", "map", "map_sorted", "col_sorted", "cmap_fun")) {
             warning(sprintf("Untypical metadata entry '%s' found in colormesh metadata.\n", mde));
         }
     }
@@ -500,4 +552,3 @@ fs.coloredmesh <- function(mesh, col, hemi, render=TRUE, metadata=NULL) {
     return(cm);
 }
 
-
