@@ -1,6 +1,6 @@
 #' @title Transform first character of a string to uppercase.
 #'
-#' @description Transform first character of a string to uppercase. This is useful when labeling plots. Important: this function does not know about different encodings, languages or anything, it just calls \code{\link[base]{toupper}} for the first character.
+#' @description Transform first character of a string to uppercase. This is useful when labeling plots. Important: this function does not know about different encodings, languages or anything, it just calls \code{\link{toupper}} for the first character.
 #'
 #' @param word, string. Any string.
 #'
@@ -474,7 +474,7 @@ hemilist.unwrap <- function(hemi_list, hemi=NULL, allow_null_list=FALSE) {
 #'
 #' @param hemi_list named list, can have entries 'lh' and/or 'rh'
 #'
-#' @return the data combined with \code{\link[base]{c}}, or NULL if both entries are NULL.
+#' @return the data combined with \code{\link{c}}, or NULL if both entries are NULL.
 #'
 #' @export
 hemilist.get.combined.data <- function(hemi_list) {
@@ -508,7 +508,7 @@ is.hemilist <- function(x) {
 
 #' @title Create final `makecmap_options` list
 #'
-#' @description Create final makecmap_options to pass to \code{\link[squash]{makecmap}} from existing `makecmap_options` and a colormap function. Used in the vis functions, like \code{\link[fsbrain]{vis.subject.morph.native}}, see the note.
+#' @description Create final makecmap_options to pass to \code{\link{makecmap}} from existing `makecmap_options` and a colormap function. Used in the vis functions, like \code{\link[fsbrain]{vis.subject.morph.native}}, see the note.
 #'
 #' @param makecmap_options list of `makecmap_options` or `NULL`
 #'
@@ -551,16 +551,19 @@ makecmakeopts.merge <- function(makecmap_options, colormap, default_colormap=squ
 #'
 #' @param listkeys vector of character strings, the nested names of the lists
 #'
-#' @return the value at the path through the lists, or NULL if no such path exists
+#' @param default the default value to return in case the requested value is `NULL`.
+#'
+#' @return the value at the path through the lists, or `NULL` (or the 'default') if no such path exists.
 #'
 #' @examples
 #'    data = list("regions"=list("frontal"=list("thickness"=2.3, "area"=2345)));
 #'    getIn(data, c("regions", "frontal", "thickness"));       # 2.3
 #'    getIn(data, c("regions", "frontal", "nosuchentry"));     # NULL
 #'    getIn(data, c("regions", "nosuchregion", "thickness"));  # NULL
+#'    getIn(data, c("regions", "nosuchregion", "thickness"), default=14);  # 14
 #'
 #' @export
-getIn <- function(named_list, listkeys) {
+getIn <- function(named_list, listkeys, default=NULL) {
   num_keys = length(listkeys);
   if(length(named_list) < 1L | num_keys  < 1L) {
     return(NULL);
@@ -588,6 +591,7 @@ getIn <- function(named_list, listkeys) {
   }
 }
 
+
 #' @title Check for values in nested named lists
 #'
 #' @param named_list a named list
@@ -664,6 +668,30 @@ find.subjectsdir.of <- function(subject_id='fsaverage', mustWork=FALSE) {
 }
 
 
+#' @title Return path to fsaverage dir.
+#'
+#' @return the path to the fsaverage directory (NOT including the 'fsaverage' dir itself).
+#'
+#' @note This function will stop (i.e., raise an error) if the directory cannot be found.
+#'
+#' @export
+fsaverage.path <- function() {
+    return(find.subjectsdir.of(subject_id='fsaverage', mustWork=TRUE));
+}
+
+
+#' @title Return FreeSurfer path.
+#'
+#' @return the FreeSurfer path, typically what the environment variable `FREESURFER_HOME` points to.
+#'
+#' @note This function will stop (i.e., raise an error) if the directory cannot be found.
+#'
+#' @export
+fs.home <- function() {
+    return(find.freesurferhome(mustWork=TRUE));
+}
+
+
 #' @title Find the FREESURFER_HOME directory on disk.
 #'
 #' @description Try to find directory containing the FreeSurfer installation, based on environment variables and *educated guessing*.
@@ -735,3 +763,32 @@ find.freesurferhome <- function(mustWork=FALSE) {
 rglot <- function() {
     return(list('windowRect' = c(50, 50, 800, 800)));
 }
+
+
+#' @title Split morph data vector at hemisphere boundary.
+#'
+#' @description Given a single vector of per-vertex data for a mesh, split it at the hemi boundary. This is achieved by loading the respective surface and checking the number of vertices for the 2 hemispheres.
+#'
+#' @param vdata numerical vector of data for both hemispheres, one value per vertex
+#'
+#' @param surface the surface to load to determine the vertex counts
+#'
+#' @inheritParams subject.morph.native
+#'
+#' @note Instead of calling this function to split the data, you could use the 'split_by_hemi' parameter of \code{\link[fsbrain]{subject.morph.native}}.
+#'
+#' @return a hemilist, each entry contains the data part of the respective hemi.
+#' @export
+vdata.split.by.hemi <- function(subjects_dir, subject_id, vdata, surface='white') {
+  lh_surf = subject.surface(subjects_dir, subject_id, surface=surface, hemi='lh');
+  rh_surf = subject.surface(subjects_dir, subject_id, surface=surface, hemi='rh');
+  num_verts_lh = nrow(lh_surf$vertices);
+  num_verts_rh = nrow(rh_surf$vertices);
+  if(length(vdata) != num_verts_lh+num_verts_rh) {
+    if(length(vdata) == (163842*2L)) {
+      warning("Hint: The length of 'vdata' matches the number of vertices in the fsaverage template. Wrong 'subject_id' parameter with standard space data?");
+    }
+    stop(sprintf("Cannot split data: surfaces contain a total of %d vertices (lh=%d, rh=%d), but vdata has length %d. Lengths must match.\n", (num_verts_lh+num_verts_rh), num_verts_lh, num_verts_rh, length(vdata)));
+  }
+  return(list('lh'=vdata[1:num_verts_lh], 'rh'=vdata[(num_verts_lh+1L):(num_verts_lh+num_verts_rh)]));
+}
